# PyTree Utilities

## Core Utilities
::: fdtdx.core.jax.pytrees.extended_autoinit
::: fdtdx.core.jax.pytrees.field
::: fdtdx.core.jax.pytrees.frozen_field
::: fdtdx.core.jax.pytrees.frozen_private_field

## Tree Classes and Fields
::: fdtdx.core.jax.pytrees.ExtendedTreeClassIndexer
::: fdtdx.core.jax.pytrees.ExtendedTreeClass
